@@ -188,12 +188,16 @@ impl TextDirection {
     /// assert_eq!(TextDirection::parse("invalid"), None);
     /// ```
     pub fn parse(s: &str) -> Option<Self> {
-        match s.to_lowercase().as_str() {
-            "ltr" => Some(Self::LeftToRight),
-            "rtl" => Some(Self::RightToLeft),
-            "auto" => Some(Self::Auto),
-            _ => None,
+        if s.eq_ignore_ascii_case("ltr") {
+            return Some(Self::LeftToRight);
         }
+        if s.eq_ignore_ascii_case("rtl") {
+            return Some(Self::RightToLeft);
+        }
+        if s.eq_ignore_ascii_case("auto") {
+            return Some(Self::Auto);
+        }
+        None
     }
 }
 
@@ -613,6 +617,31 @@ pub struct MetadataConfig {
     pub max_structured_data_size: usize,
 }
 
+/// Partial update for MetadataConfig.
+#[derive(Debug, Clone, Default)]
+#[cfg_attr(any(feature = "serde", feature = "metadata"), derive(serde::Deserialize))]
+#[cfg_attr(any(feature = "serde", feature = "metadata"), serde(rename_all = "camelCase"))]
+pub struct MetadataConfigUpdate {
+    #[cfg_attr(any(feature = "serde", feature = "metadata"), serde(alias = "extract_document"))]
+    pub extract_document: Option<bool>,
+    #[cfg_attr(any(feature = "serde", feature = "metadata"), serde(alias = "extract_headers"))]
+    pub extract_headers: Option<bool>,
+    #[cfg_attr(any(feature = "serde", feature = "metadata"), serde(alias = "extract_links"))]
+    pub extract_links: Option<bool>,
+    #[cfg_attr(any(feature = "serde", feature = "metadata"), serde(alias = "extract_images"))]
+    pub extract_images: Option<bool>,
+    #[cfg_attr(
+        any(feature = "serde", feature = "metadata"),
+        serde(alias = "extract_structured_data")
+    )]
+    pub extract_structured_data: Option<bool>,
+    #[cfg_attr(
+        any(feature = "serde", feature = "metadata"),
+        serde(alias = "max_structured_data_size")
+    )]
+    pub max_structured_data_size: Option<usize>,
+}
+
 impl Default for MetadataConfig {
     /// Create default metadata configuration.
     ///
@@ -629,6 +658,49 @@ impl Default for MetadataConfig {
     }
 }
 
+impl MetadataConfig {
+    pub fn any_enabled(&self) -> bool {
+        self.extract_document
+            || self.extract_headers
+            || self.extract_links
+            || self.extract_images
+            || self.extract_structured_data
+    }
+
+    pub fn apply_update(&mut self, update: MetadataConfigUpdate) {
+        if let Some(extract_document) = update.extract_document {
+            self.extract_document = extract_document;
+        }
+        if let Some(extract_headers) = update.extract_headers {
+            self.extract_headers = extract_headers;
+        }
+        if let Some(extract_links) = update.extract_links {
+            self.extract_links = extract_links;
+        }
+        if let Some(extract_images) = update.extract_images {
+            self.extract_images = extract_images;
+        }
+        if let Some(extract_structured_data) = update.extract_structured_data {
+            self.extract_structured_data = extract_structured_data;
+        }
+        if let Some(max_structured_data_size) = update.max_structured_data_size {
+            self.max_structured_data_size = max_structured_data_size;
+        }
+    }
+
+    pub fn from_update(update: MetadataConfigUpdate) -> Self {
+        let mut config = Self::default();
+        config.apply_update(update);
+        config
+    }
+}
+
+impl From<MetadataConfigUpdate> for MetadataConfig {
+    fn from(update: MetadataConfigUpdate) -> Self {
+        Self::from_update(update)
+    }
+}
+
 /// Comprehensive metadata extraction result from HTML document.
 ///
 /// Contains all extracted metadata types in a single structure,
@@ -873,6 +945,9 @@ impl MetadataCollector {
         }
 
         let content_size = json_content.len();
+        if content_size > self.config.max_structured_data_size {
+            return;
+        }
         if self.structured_data_size + content_size > self.config.max_structured_data_size {
             return;
         }
@@ -890,6 +965,9 @@ impl MetadataCollector {
     ///
     /// * `metadata` - BTreeMap of metadata key-value pairs
     pub(crate) fn set_head_metadata(&mut self, metadata: BTreeMap<String, String>) {
+        if !self.config.extract_document {
+            return;
+        }
         self.head_metadata.extend(metadata);
     }
 
@@ -902,6 +980,9 @@ impl MetadataCollector {
     ///
     /// * `lang` - Language code (e.g., "en", "es", "fr")
     pub(crate) fn set_language(&mut self, lang: String) {
+        if !self.config.extract_document {
+            return;
+        }
         if self.lang.is_none() {
             self.lang = Some(lang);
         }
@@ -916,43 +997,80 @@ impl MetadataCollector {
     ///
     /// * `dir` - Direction string ("ltr", "rtl", or "auto")
     pub(crate) fn set_text_direction(&mut self, dir: String) {
+        if !self.config.extract_document {
+            return;
+        }
         if self.dir.is_none() {
             self.dir = Some(dir);
         }
     }
 
+    pub(crate) fn wants_document(&self) -> bool {
+        self.config.extract_document
+    }
+
+    pub(crate) fn wants_headers(&self) -> bool {
+        self.config.extract_headers
+    }
+
+    pub(crate) fn wants_links(&self) -> bool {
+        self.config.extract_links
+    }
+
+    pub(crate) fn wants_images(&self) -> bool {
+        self.config.extract_images
+    }
+
+    pub(crate) fn wants_structured_data(&self) -> bool {
+        self.config.extract_structured_data
+    }
+
     /// Extract document metadata from collected head metadata.
     ///
     /// Parses head metadata into structured document metadata,
     /// handling special cases like Open Graph, Twitter Card, keywords, etc.
     #[allow(dead_code)]
-    fn extract_document_metadata(&self) -> DocumentMetadata {
+    fn extract_document_metadata(
+        head_metadata: BTreeMap<String, String>,
+        lang: Option<String>,
+        dir: Option<String>,
+    ) -> DocumentMetadata {
         let mut doc = DocumentMetadata::default();
 
-        for (raw_key, value) in &self.head_metadata {
-            let mut key = raw_key.to_lowercase();
+        for (raw_key, value) in head_metadata {
+            let mut key = raw_key.as_str();
+            let mut replaced_key: Option<String> = None;
 
             if let Some(stripped) = key.strip_prefix("meta-") {
-                key = stripped.to_string();
+                key = stripped;
             }
 
-            if key.contains(':') {
-                key = key.replace(':', "-");
+            if key.as_bytes().contains(&b':') {
+                replaced_key = Some(key.replace(':', "-"));
+                key = replaced_key.as_deref().unwrap_or(key);
             }
 
-            match key.as_str() {
-                "title" => doc.title = Some(value.clone()),
-                "description" => doc.description = Some(value.clone()),
-                "author" => doc.author = Some(value.clone()),
-                "canonical" => doc.canonical_url = Some(value.clone()),
-                "base" | "base-href" => doc.base_href = Some(value.clone()),
+            match key {
+                "title" => doc.title = Some(value),
+                "description" => doc.description = Some(value),
+                "author" => doc.author = Some(value),
+                "canonical" => doc.canonical_url = Some(value),
+                "base" | "base-href" => doc.base_href = Some(value),
                 key if key.starts_with("og-") => {
-                    let og_key = key.trim_start_matches("og-").replace('-', "_");
-                    doc.open_graph.insert(og_key, value.clone());
+                    let og_key = if key.as_bytes().contains(&b'-') {
+                        key.trim_start_matches("og-").replace('-', "_")
+                    } else {
+                        key.trim_start_matches("og-").to_string()
+                    };
+                    doc.open_graph.insert(og_key, value);
                 }
                 key if key.starts_with("twitter-") => {
-                    let tw_key = key.trim_start_matches("twitter-").replace('-', "_");
-                    doc.twitter_card.insert(tw_key, value.clone());
+                    let tw_key = if key.as_bytes().contains(&b'-') {
+                        key.trim_start_matches("twitter-").replace('-', "_")
+                    } else {
+                        key.trim_start_matches("twitter-").to_string()
+                    };
+                    doc.twitter_card.insert(tw_key, value);
                 }
                 "keywords" => {
                     doc.keywords = value
@@ -962,17 +1080,24 @@ impl MetadataCollector {
                         .collect();
                 }
                 _ => {
-                    doc.meta_tags.insert(key.clone(), value.clone());
+                    let meta_key = if key.as_ptr() == raw_key.as_ptr() && key.len() == raw_key.len() {
+                        raw_key
+                    } else if let Some(replaced) = replaced_key {
+                        replaced
+                    } else {
+                        key.to_string()
+                    };
+                    doc.meta_tags.insert(meta_key, value);
                 }
             }
         }
 
-        if let Some(ref lang) = self.lang {
-            doc.language = Some(lang.clone());
+        if let Some(lang) = lang {
+            doc.language = Some(lang);
         }
 
-        if let Some(ref dir) = self.dir {
-            if let Some(parsed_dir) = TextDirection::parse(dir) {
+        if let Some(dir) = dir {
+            if let Some(parsed_dir) = TextDirection::parse(&dir) {
                 doc.text_direction = Some(parsed_dir);
             }
         }
@@ -982,17 +1107,36 @@ impl MetadataCollector {
 
     /// Extract structured data blocks into StructuredData items.
     #[allow(dead_code)]
-    fn extract_structured_data(&self) -> Vec<StructuredData> {
-        let mut result = Vec::with_capacity(self.json_ld.len());
+    fn extract_structured_data(json_ld: Vec<String>) -> Vec<StructuredData> {
+        let mut result = Vec::with_capacity(json_ld.len());
 
-        for json_str in &self.json_ld {
-            let schema_type = serde_json::from_str::<serde_json::Value>(json_str)
-                .ok()
-                .and_then(|v| v.get("@type").and_then(|t| t.as_str().map(|s| s.to_string())));
+        for json_str in json_ld {
+            let schema_type = Self::scan_schema_type(&json_str)
+                .or_else(|| {
+                    if json_str.contains("\"@type\"") {
+                        serde_json::from_str::<serde_json::Value>(&json_str)
+                            .ok()
+                            .and_then(|v| v.get("@type").and_then(|t| t.as_str().map(|s| s.to_string())))
+                    } else {
+                        None
+                    }
+                })
+                .or_else(|| {
+                    if !json_str.contains("\"@graph\"") {
+                        return None;
+                    }
+
+                    let value = serde_json::from_str::<serde_json::Value>(&json_str).ok()?;
+                    let graph = value.get("@graph")?;
+                    let items = graph.as_array()?;
+                    items
+                        .iter()
+                        .find_map(|item| item.get("@type").and_then(|t| t.as_str().map(|s| s.to_string())))
+                });
 
             result.push(StructuredData {
                 data_type: StructuredDataType::JsonLd,
-                raw_json: json_str.clone(),
+                raw_json: json_str,
                 schema_type,
             });
         }
@@ -1000,6 +1144,64 @@ impl MetadataCollector {
         result
     }
 
+    fn scan_schema_type(json_str: &str) -> Option<String> {
+        let needle = "\"@type\"";
+        let start = json_str.find(needle)? + needle.len();
+        let bytes = json_str.as_bytes();
+        let mut i = start;
+
+        while i < bytes.len() && bytes[i].is_ascii_whitespace() {
+            i += 1;
+        }
+        if i >= bytes.len() || bytes[i] != b':' {
+            return None;
+        }
+        i += 1;
+        while i < bytes.len() && bytes[i].is_ascii_whitespace() {
+            i += 1;
+        }
+        if i >= bytes.len() {
+            return None;
+        }
+
+        if bytes[i] == b'[' {
+            i += 1;
+            while i < bytes.len() && bytes[i].is_ascii_whitespace() {
+                i += 1;
+            }
+            if i >= bytes.len() || bytes[i] != b'"' {
+                return None;
+            }
+        } else if bytes[i] != b'"' {
+            return None;
+        }
+
+        let start_quote = i;
+        i += 1;
+        let mut escaped = false;
+        while i < bytes.len() {
+            let byte = bytes[i];
+            if escaped {
+                escaped = false;
+                i += 1;
+                continue;
+            }
+            if byte == b'\\' {
+                escaped = true;
+                i += 1;
+                continue;
+            }
+            if byte == b'"' {
+                let end_quote = i;
+                let slice = &json_str[start_quote..=end_quote];
+                return serde_json::from_str::<String>(slice).ok();
+            }
+            i += 1;
+        }
+
+        None
+    }
+
     /// Finish collection and return all extracted metadata.
     ///
     /// Performs final processing, validation, and consolidation of all
@@ -1010,8 +1212,8 @@ impl MetadataCollector {
     /// Complete [`ExtendedMetadata`] with all extracted information.
     #[allow(dead_code)]
     pub(crate) fn finish(self) -> ExtendedMetadata {
-        let structured_data = self.extract_structured_data();
-        let document = self.extract_document_metadata();
+        let structured_data = Self::extract_structured_data(self.json_ld);
+        let document = Self::extract_document_metadata(self.head_metadata, self.lang, self.dir);
 
         ExtendedMetadata {
             document,
